@@ -1,6 +1,5 @@
 package Dist::Zilla::PluginBundle::Author::WATERKIP;
 use Moose;
-our $VERSION = '1.0';
 
 # ABSTRACT: An plugin bundle for all distributions by WATERKIP
 # KEYWORDS: author bundle distribution tool
@@ -9,11 +8,6 @@ use Moose::Util::TypeConstraints qw(enum);
 use List::Util qw(uniq any first);
 use namespace::autoclean;
 
-# Have multi value args
-sub mvp_multivalue_args {
-    return qw(copy_file_from_release);
-}
-
 with
     'Dist::Zilla::Role::PluginBundle::Easy',
     'Dist::Zilla::Role::PluginBundle::PluginRemover' => { -version => '0.103' },
@@ -40,6 +34,7 @@ has license => (
     default => sub { $_[0]->payload->{license} // 'LICENSE' },
 );
 
+
 has copy_file_from_release => (
     isa => 'ArrayRef[Str]',
     init_arg => undef,
@@ -49,11 +44,19 @@ has copy_file_from_release => (
     handles => { copy_files_from_release => 'elements' },
 );
 
+has debug => (
+    is => 'ro', isa => 'Bool',
+    init_arg => undef,
+    lazy => 1,
+    default => sub { $ENV{DZIL_AUTHOR_DEBUG} // $_[0]->payload->{debug} // 0 },
+);
+
 around copy_files_from_release => sub {
     my $orig = shift; my $self = shift;
     sort(uniq(
             $self->$orig(@_),
-            qw(LICENCE LICENSE CONTRIBUTING Changes CHANGES ppport.h INSTALL Makefile.PL cpanfile README README.md)
+            qw(LICENCE LICENSE CONTRIBUTING Changes CHANGES ppport.h INSTALL
+            Makefile.PL cpanfile README README.md Build.PL)
     ));
 };
 
@@ -68,23 +71,10 @@ has authority => (
 );
 
 has fake_release => (
-    is       => 'ro',
-    isa      => 'Bool',
+    is => 'ro', isa => 'Bool',
     init_arg => undef,
-    lazy     => 1,
-    default  => sub {
-            $ENV{FAKE_RELEASE}
-            || $_[0]->payload->{fake_release} // 0;
-    },
-);
-
-has test_release => (
-    is       => 'ro',
-    isa      => 'Bool',
-    init_arg => undef,
-    lazy     => 1,
-    # Currently all our releases are test releases
-    default => sub { $_[0]->payload->{test_release} // 1 },
+    lazy => 1,
+    default => sub { $ENV{FAKE_RELEASE} || $_[0]->payload->{fake_release} // 0 },
 );
 
 my @network_plugins = qw(
@@ -111,6 +101,15 @@ sub configure {
     my $self = shift;
 
 
+    if ($self->debug) {
+        use Data::Dumper;
+        _warn_me(
+            Dumper {
+                payload => $self->payload,
+            }
+        );
+    }
+
     if (!-d '.git' and -f 'META.json' and !exists $removed{'Git::GatherDir'}) {
         _warn_me(
             '.git is missing and META.json is present -- this looks like a CPAN download rather than a git repository. You should probably run '
@@ -123,42 +122,38 @@ sub configure {
         [
             'Git::GatherDir' => {
                 do {
-                    my @filenames = $self->copy_files_from_release;
+                    my @filenames
+                        = grep { -e } $self->copy_files_from_release;
                     @filenames ? (exclude_filename => \@filenames) : ();
                 },
             },
         ],
 
-        qw(MetaYAML MetaJSON Readme ManifestSkip Manifest),
-
-        $self->test_release ? () :
-        [
-            'Git::Check' => {
-                allow_dirty     => [$self->copy_files_from_release],
-            }
-        ],
-
+        qw(PruneCruft ManifestSkip MetaYAML MetaJSON),
 
         [ 'License' => { filename => $self->license } ],
 
-        ['PruneCruft'],
-        ['ExtraTests'],
-        ['ExecDir'],
-        ['ShareDir'],
-        ['MakeMaker'],
-        ['ChangelogFromGit'],
-        #['TestRelease'],
+        qw(Readme ExtraTests ExecDir ShareDir MakeMaker Manifest
+           TestRelease PodWeaver),
+
+        [ 'AutoPrereqs' => { skip => [qw(^perl$ ^namespace::autoclean$ ^Moose$)]}],
+        [ 'Prereqs::AuthorDeps' => { ':version' => '0.006' } ],
+        [ 'MinimumPerl'         => { ':version' => '1.006', configure_finder => ':NoFiles' } ],
         ['CPANFile'],
 
+
+#        [ 'PrereqsClean'],
+
         $self->fake_release ? do { _warn_me('FAKE_RELEASE set - not uploading to CPAN'); 'FakeRelease' }
            : 'UploadToCPAN',
 
+        # Perhaps do copy files from build first?
+        # [ 'CopyFilesFromBuild' => { filename => [ $self->copy_files_from_release ] } ],
         [ 'CopyFilesFromRelease' => { filename => [ $self->copy_files_from_release ] } ],
+        # Don't generate a change log from git just yet, figure out
+        # first what our workflow will be
+        #['ChangelogFromGit' => { include_message => '^release' } ],
 
-        [ 'PodWeaver'],
-        [ 'AutoPrereqs'],
-        [ 'Prereqs::AuthorDeps' => { ':version' => '0.006' } ],
-        [ 'MinimumPerl'         => { ':version' => '1.006', configure_finder => ':NoFiles' } ],
 
     );
 
@@ -196,11 +191,21 @@ Dist::Zilla::PluginBundle::Author::WATERKIP - An plugin bundle for all distribut
 
 =head1 VERSION
 
-version 1.0
+version 1.1
+
+=head1 SYNOPSIS
+
+In your F<dist.ini>:
+
+    [@Author::WATERKIP]
+
+=head1 SEE ALSO
+
+I took inspiration from L<Dist::Zilla::PluginBundle::Author::ETHER>
 
 =head1 AUTHOR
 
-Wesley Schwengle <wesley@schwengle.net>
+Wesley Schwengle <waterkip@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
